==> hl7v2json-1.0.0.tar.gz: hl7v2json-1.0.0/tests/samples.py <==
# -*- coding: utf-8 -*-


message1 = '\r'.join([
    'MSH|^~\&|MegaReg|XYZHospC|SuperOE|XYZImgCtr|20060529090131||ADT^A01^ADT_A01|01052901|P|2.5',
    'EVN||20060529090100||||20060529090000',
    'PID|||56782445^^^UAReg^PI||KLEINSAMPLE^BARRY^Q^JR||19620910|M||2028-9^^HL70005^RA99113^^XYZ|260 GOODWIN CREST '
    'DRIVE^^BIRMINGHAM^AL^35209^^M~NICKELL’S PICKLES^10000 W 100TH '
    'AVE^BIRMINGHAM^AL^35200^^O|||||||0105I30001^^^99DEF^AN',
    'PV1||I|W^389^1^UABH^^^^3||||12345^MORGAN^REX^J^^^MD^0010^UAMC^L||67890^GRAINGER^LUCY^X^^^MD^0010^UAMC^L|MED'
    '|||||A0||13579^POTTER^SHERMAN^T^^^MD^0010^UAMC^L|||||||||||||||||||||||||||20060529090000',
    'OBX|1|NM|^Body Height||1.80|m^Meter^ISO+|||||F',
    'AL1|1||^ASPIRIN',
    'DG1|1||786.50^CHEST PAIN, UNSPECIFIED^I9|||A'
])

message2 = '\r'.join([
    'MSH|^~&|ADT1|MCM|LABADT|MCM|198808181126|SECURITY|ADT^A04|MSG00001|P|2.4',
    'EVN|A01-|19880818112300',
    'PID|||PATID1234^5^M11||JONES^WILLIAM^A^III&Jr||19610615|M-||2106-3|1200 N ELM '
    'STREET^^GREENSBORO^NC^27401-1020|GL|( '
    '919)379-1212|(919)271-3434~(919)277-3114||S||PATID12345001^2^M10|123456789|9-87654^NC',
    'NK1|1|JONES^BARBARA^K|SPO|||||20011105',
    'PV1|1|I|2000^2012^01||||004777^LEBAUER^SIDNEY^J.|||SUR||-||1|A0-',
    'AL1|1||^PENICILLIN||PRODUCES HIVES~RASH',
    'DG1|001|I9|1550|MAL NEO LIVER, PRIMARY|19880501103005|F||',
    'PR1|2234|M11|111^CODE151|COMMON PROCEDURES|198809081123',
    'GT1|1122|1519|BILL^GATES^A',
    'IN1|001|A357|1234|BCMD|||||132987',
    'IN2|ID1551001|SSN12345678',
])

==> hl7v2json-1.0.1.tar.gz: hl7v2json-1.0.1/tests/samples.py <==
# -*- coding: utf-8 -*-


message1 = '\r'.join([
    'MSH|^~\&|MegaReg|XYZHospC|SuperOE|XYZImgCtr|20060529090131||ADT^A01^ADT_A01|01052901|P|2.5',
    'EVN||20060529090100||||20060529090000',
    'PID|||56782445^^^UAReg^PI||KLEINSAMPLE^BARRY^Q^JR||19620910|M||2028-9^^HL70005^RA99113^^XYZ|260 GOODWIN CREST '
    'DRIVE^^BIRMINGHAM^AL^35209^^M~NICKELL’S PICKLES^10000 W 100TH '
    'AVE^BIRMINGHAM^AL^35200^^O|||||||0105I30001^^^99DEF^AN',
    'PV1||I|W^389^1^UABH^^^^3||||12345^MORGAN^REX^J^^^MD^0010^UAMC^L||67890^GRAINGER^LUCY^X^^^MD^0010^UAMC^L|MED'
    '|||||A0||13579^POTTER^SHERMAN^T^^^MD^0010^UAMC^L|||||||||||||||||||||||||||20060529090000',
    'OBX|1|NM|^Body Height||1.80|m^Meter^ISO+|||||F',
    'AL1|1||^ASPIRIN',
    'DG1|1||786.50^CHEST PAIN, UNSPECIFIED^I9|||A'
])

message2 = '\r'.join([
    'MSH|^~&|ADT1|MCM|LABADT|MCM|198808181126|SECURITY|ADT^A04|MSG00001|P|2.4',
    'EVN|A01-|19880818112300',
    'PID|||PATID1234^5^M11||JONES^WILLIAM^A^III&Jr||19610615|M-||2106-3|1200 N ELM '
    'STREET^^GREENSBORO^NC^27401-1020|GL|( '
    '919)379-1212|(919)271-3434~(919)277-3114||S||PATID12345001^2^M10|123456789|9-87654^NC',
    'NK1|1|JONES^BARBARA^K|SPO|||||20011105',
    'PV1|1|I|2000^2012^01||||004777^LEBAUER^SIDNEY^J.|||SUR||-||1|A0-',
    'AL1|1||^PENICILLIN||PRODUCES HIVES~RASH',
    'DG1|001|I9|1550|MAL NEO LIVER, PRIMARY|19880501103005|F||',
    'PR1|2234|M11|111^CODE151|COMMON PROCEDURES|198809081123',
    'GT1|1122|1519|BILL^GATES^A',
    'IN1|001|A357|1234|BCMD|||||132987',
    'IN2|ID1551001|SSN12345678',
])

message3 = '\r'.join([
    "MSH|^~\\&|PATIENTPING_ADT|23472^New Hanover RMC Orthopedic Hospital^HOS|RECEIVING_APP|254468^Pearl Health|20220529230000||ADT^A11|328bcea0-dfc4-11ec-97b3-cfe19de0a160|T|2.7",
    "EVN|A11|20220529171100||CANCEL_ENCOUNTER",
    "PID|1|p-847559c1-c037-11ec-ab6d-b5fdaa507fbb^^^PP^PP|PEARL^^^default^default||JONES^WILLIAM^||19341006|M|||^^^NC^28405||9107913492|||||18301049|",
    "PD1||||999999999^Klein^Isidore^^^^",
    "PV1|1|E|||||||||||||||||18301049|||||||||||||||||||||||||||||||136010654",
    'IN1|001|A357|1234|BCMD|||||132987',
    'IN1|002|A357|1234|BCMD|||||132987',
    "ZMD|30cf2ac0-dfc4-11ec-97d8-191cc28dd728",
])
